@@ -3,14 +3,14 @@
 /*  CCOPYRIGHT */
 
 #include "options.h"
+#include "buildno.h"
 
 namespace Utilities {
 
-  void OptionParser::usage()
-  {
-    cerr << endl << progname_ << endl << endl;
-    cerr << "Usage: " << endl << example_ << endl;
+  using namespace std;
 
+  void OptionParser::describe_options()
+  {
     for(Options::iterator option = options_.begin(); option != options_.end(); 
 	option++)
       {
@@ -20,7 +20,7 @@ namespace Utilities {
 	    cerr << endl << "Compulsory arguments (You MUST set one or more of):" << endl;
 	    banner = false;
 	  }
-	  cerr << **option << endl;
+	  (*option)->usage(cerr); cerr << endl;
 	}
       }
 
@@ -34,7 +34,7 @@ namespace Utilities {
 	    cerr << endl << "Optional arguments (You may optionally specify one or more of):" << endl;
 	    banner = false;
 	  }
-	  cerr << **optionx << endl;
+	  (*optionx)->usage(cerr); cerr << endl;
 	}
       }
 
@@ -42,4 +42,20 @@ namespace Utilities {
     cerr << endl;
   }
 
+  void OptionParser::brief_usage()
+  {
+    cerr << progname_ << endl << endl;
+    cerr << "Usage: " << endl << example_ << endl;
+
+    describe_options();
+  }
+
+  void OptionParser::usage()
+  {
+    cerr << endl << "Part of FSL (build " << build << ")"<< endl;
+    cerr << progname_ << endl << endl;
+    cerr << "Usage: " << endl << example_ << endl;
+
+    describe_options();
+  }
 }
