@@ -9,7 +9,7 @@
 /*  CCOPYRIGHT */
 
 /****************************************************************************
-** $Id: application.cpp,v 1.146.2.2 2009/05/27 16:52:28 flitney Exp $
+** $Id: application.cpp,v 1.146.2.3 2010/04/19 15:46:29 flitney Exp $
 **
 ** Copyright (C) 2002 University of Oxford.  All rights reserved.
 **
@@ -125,7 +125,8 @@ ApplicationWindow::ApplicationWindow(ApplicationOptions& options):
   int dh(QApplication::desktop()->height());
 
   setMinimumSize(200,200);
-  setGeometry(Preferences::getInstance()->inqGeometry(dw, dh));
+  Preferences p;
+  setGeometry(p.inqGeometry(dw, dh));
 
   setupStatusBar(); 
 
@@ -609,7 +610,8 @@ void ApplicationWindow::fileAdd()
 
 void ApplicationWindow::fileOpen152(void)
 {
-  QString fn(QFileDialog::getOpenFileName(Preferences::getInstance()->inqMni152().c_str(),
+  Preferences p;
+  QString fn(QFileDialog::getOpenFileName(p.inqMni152().c_str(),
 					  "Image files (*.hdr *.hdr.gz *.nii *.nii.gz)", 
 					  this ));
 
@@ -629,7 +631,8 @@ void ApplicationWindow::fileOpen152(void)
 
 void ApplicationWindow::fileAdd152(void)
 {
-  QString fn(QFileDialog::getOpenFileName(Preferences::getInstance()->inqMni152().c_str(),
+  Preferences p;
+  QString fn(QFileDialog::getOpenFileName(p.inqMni152().c_str(),
 					  "Image files (*.hdr *.hdr.gz *.nii *.nii.gz)", 
 					  this ));
 
@@ -1250,7 +1253,8 @@ void ApplicationWindow::childWindowClose(QCloseEvent* e)
 
 void ApplicationWindow::closeEvent(QCloseEvent* e)
 {
-  Preferences::getInstance()->setGeometry(geometry());
+  Preferences p;
+  p.setGeometry(geometry());
 
   if(windowListEmpty())
     {
