@@ -24,7 +24,8 @@ AssistantClient* AssistantClient::m_instance=0;
 AssistantClient* AssistantClient::getInstance()
 {
   if(!m_instance) {
-    QString path( Preferences::getInstance()->inqAssistantPath() );
+    Preferences p;
+    QString path( p.inqAssistantPath() );
     m_instance = new AssistantClient(path);
   }
   return m_instance;
@@ -33,7 +34,8 @@ AssistantClient* AssistantClient::getInstance()
 AssistantClient::AssistantClient(const QString& path):
   QAssistantClient( path, qApp->mainWidget())
 {
-  m_docPath = Preferences::getInstance()->inqFSLDir() + QString("/doc/fslview");
+  Preferences p;
+  m_docPath = p.inqFSLDir() + QString("/doc/fslview");
   QStringList args;
 
   args << "-profile" << QString("%1/fslview.adp").arg(m_docPath);
