@@ -139,6 +139,17 @@ void Cursor::setCursor(short x, short y, short z, short v)
   notify();
 }
 
+//! @brief Set the cursor position
+//! @param v the volume number
+void Cursor::setVolume(short v)
+{
+  TRACKER("Cursor::setVolume(short v)");
+  MESSAGE(QString("v = %1").arg(v));
+
+  setV(v);
+  notify();
+}
+
 //! @brief Attach a view to this cursor
 //! @param o handle of a view which requires notification of any 
 //!          changes to this cursor
