@@ -13,7 +13,6 @@
 #include "cursorwidget.h"
 #include "imagedisplaysetting.h"
 #include "overlaylist.h"
-#include "tracker.h"
 
 #include <qspinbox.h>
 #include <qlineedit.h>
@@ -26,6 +25,9 @@
 
 using namespace std;
 
+//#define DEBUGGING
+#include "tracker.h"
+
 class VoxBox: public QSpinBox
 {
  public:
@@ -84,7 +86,7 @@ CursorWidget::CursorWidget(QWidget *parent, const Cursor::Handle& c, OverlayList
   connect(m_yMmBox,SIGNAL(returnPressed()), SLOT(mmBoxChanged()));
   connect(m_zMmBox,SIGNAL(returnPressed()), SLOT(mmBoxChanged()));
   
-  connect(m_volumeBox, SIGNAL(valueChanged(int)), SIGNAL(volumeValueChanged(int)));
+  connect(m_volumeBox, SIGNAL(valueChanged(int)), SLOT(internalVolumeValueChanged(int)));
 
   setInputValidators();
 
@@ -95,6 +97,13 @@ CursorWidget::CursorWidget(QWidget *parent, const Cursor::Handle& c, OverlayList
   update(m_cursor);
 }
 
+void CursorWidget::internalVolumeValueChanged(int v)
+{
+  m_overlayList->getActiveMetaImage()->getDs()->setCurrentVolume(v);
+  //  m_cursor->setVolume(v);
+  emit volumeValueChanged(v);
+}
+
 CursorWidget::~CursorWidget()
 {
   m_cursor->detach(this);
@@ -111,6 +120,8 @@ void CursorWidget::update(const Cursor::Handle& c)
 {
   TRACKER("CursorWidget::update(const Cursor::Handle& c)");
 
+  MESSAGE( QString("c = %1, %2, %3, %4").arg(c->inqX()).arg(c->inqY()).arg(c->inqZ()).arg(c->inqV()) );
+
   blockBoxSignals(true);
  
   Image::Handle image = m_overlayList->getActiveMetaImage()->getImage();
@@ -374,6 +385,9 @@ QString CursorWidget::fixMmBoxVal(QDoubleValidator* v,QString & s)
 
 void CursorWidget::setVolumeValue(int v)
 {
+  TRACKER("CursorWidget::setVolumeValue(int v)");
+  MESSAGE( QString("v = %1").arg(v) );
+
   m_volumeBox->blockSignals(true);
   m_volumeBox->setValue(v);
   m_volumeBox->blockSignals(false);
