@@ -33,7 +33,7 @@ public:
   double inqRange(){return m_range;}
 
 protected:
-  Handle countedThis() const { return boost::make_shared(m_countedThis); }
+  Handle countedThis() const { return Handle(m_countedThis); }
 
 private:
   GraphManager();
