@@ -54,11 +54,12 @@ ImageWidget::ImageWidget(QWidget* parent,        ImageGroup::Handle i,
   
   m_overlayDialog = NULL;
  
+  m_cursor->attach(this);
+  m_globalCursor->attach(this);
+
   constructToolBar();
 
   m_overlayList->attach(this);
-  m_cursor->attach(this);
-  m_globalCursor->attach(this);
 
   connect(parent, SIGNAL(windowActivated(QWidget*)), this, SLOT(windowActivated(QWidget*)));
 
@@ -77,6 +78,7 @@ ImageWidget::~ImageWidget()
 
 void ImageWidget::options()
 {
+  TRACKER("ImageWidget::options()");
   ViewOptionsDialog optionsDialog(this, m_opts);
 
   optionsDialog.m_showLabels->setEnabled(true);
@@ -86,7 +88,11 @@ void ImageWidget::options()
        m_opts = optionsDialog.getOptions();
        setLabels(m_overlayList.get());
        setMovieFrameRate(m_opts.inqMovieFrameRate());
-       m_cursor->repaint();	// Forces a redraw
+       short volume( m_overlayList->getActiveMetaImage()->getDs()->inqCurrentVolume() );
+       MESSAGE(QString("volume = %1").arg(volume));
+       setVolumeValue(volume);
+       m_cursor->setVolume(volume);
+       m_cursor->repaint();
     }
 }
 
@@ -206,12 +212,25 @@ void ImageWidget::crossHairModeChanged(int state)
   emit crossHairModeChanged(state == QButton::On); 
 }
 
+struct SetVolume
+{
+  SetVolume(int v): m_vol(v) {}
+
+  void operator()(const MetaImage::Handle& mi)
+  {
+    mi->getDs()->setCurrentVolume(m_vol);
+  }
+
+  int m_vol;
+};
 
 void ImageWidget::setVolumeValue(int n)
 {
-  TRACKER("ImageWidget::setVolume");
-  MetaImage::Handle mi = m_overlayList->getActiveMetaImage();
-  mi->getDs()->setCurrentVolume(n);
+  TRACKER("ImageWidget::setVolumeValue()");
+
+  if( m_opts.inqVolumeIndexingWithinView() )
+    for_each( m_overlayList->begin(), m_overlayList->end(), SetVolume(n) );
+
   m_cursor->setCursor(m_cursor->inqX(),m_cursor->inqY(),m_cursor->inqZ(), n);
 }
 
@@ -230,48 +249,114 @@ void ImageWidget::openOverlayDialog()
   connect(m_overlayDialog, SIGNAL(message(const QString&, int)), SIGNAL(message(const QString&, int)));
 }
 
-struct SetVolume
-{
-  SetVolume(int v): m_vol(v) {}
-
-  void operator()(const MetaImage::Handle& mi)
-  {
-    mi->getDs()->setCurrentVolume(m_vol);
-  }
-
-  int m_vol;
-};
-
 void ImageWidget::update(const Cursor::Handle& c)
 {
   TRACKER("ImageWidget::update(const Cursor::Handle& c)");
+  MESSAGE( QString("c = %1, %2, %3, %4").arg(c->inqX()).arg(c->inqY()).arg(c->inqZ()).arg(c->inqV()) );
 
   // Important - cross talk between cursor events should be co-ordinated here.
   //             If you can't explain behaviour by looking at this method
   //             then you probably are the proud owner of a nasty bug.
   MetaImage::Handle mi = m_overlayList->getActiveMetaImage();
-  if( m_opts.inqUseSharedVolume() && (mi->getInfo()->inqNumVolumes() > c->inqV()) )
+
+  bool local(c == m_cursor);
+
+  // 0 0 0 0
+  if( local && m_opts.inqUseSharedVolume() && m_opts.inqUseSharedLocation() && m_opts.inqVolumeIndexingWithinView() ) {
+    for_each( m_overlayList->begin(), m_overlayList->end(), SetVolume(c->inqV()) );
+    m_globalCursor->detach(this);
+    m_globalCursor->setCursor(c);
+    m_globalCursor->attach(this);    
+  }
+  // 0 0 0 1
+  if( local && m_opts.inqUseSharedVolume() && m_opts.inqUseSharedLocation() && !m_opts.inqVolumeIndexingWithinView() ) {
     mi->getDs()->setCurrentVolume(c->inqV());
-
-  if( m_opts.inqVolumeIndexingWithinView() )
+    m_globalCursor->detach(this);
+    m_globalCursor->setCursor(c);
+    m_globalCursor->attach(this);   
+  }
+  // 0 0 1 0
+  if( local && m_opts.inqUseSharedVolume() && !m_opts.inqUseSharedLocation() && m_opts.inqVolumeIndexingWithinView() ) {
+    for_each( m_overlayList->begin(), m_overlayList->end(), SetVolume(c->inqV()) );
+    m_globalCursor->detach(this);
+    m_globalCursor->setVolume(c->inqV());
+    m_globalCursor->attach(this);   
+  }
+  // 0 0 1 1
+  if( local && m_opts.inqUseSharedVolume() && !m_opts.inqUseSharedLocation() && !m_opts.inqVolumeIndexingWithinView() ) {
+    mi->getDs()->setCurrentVolume(c->inqV());
+    m_globalCursor->detach(this);
+    m_globalCursor->setVolume(c->inqV());
+    m_globalCursor->attach(this);   
+  }
+  // 0 1 0 0
+  if( local && !m_opts.inqUseSharedVolume() && m_opts.inqUseSharedLocation() && m_opts.inqVolumeIndexingWithinView() ) {
     for_each( m_overlayList->begin(), m_overlayList->end(), SetVolume(mi->getDs()->inqCurrentVolume()) );
-
-  if( m_opts.inqUseSharedLocation() )  // Propagate cursor changes if necessary
-    if(c == m_globalCursor) {
-      m_cursor->detach(this);
-      if( m_opts.inqUseSharedVolume() )
-	m_cursor->setCursor(c->inqX(), c->inqY(), c->inqZ(), mi->getDs()->inqCurrentVolume());
-      else
-	m_cursor->setCursor(c->inqX(), c->inqY(), c->inqZ());
-      m_cursor->attach(this);
-    } else {
-      m_globalCursor->detach(this);
-      if( m_opts.inqUseSharedVolume() )
-	m_globalCursor->setCursor(c->inqX(), c->inqY(), c->inqZ(), mi->getDs()->inqCurrentVolume());
-      else
-	m_globalCursor->setCursor(c->inqX(), c->inqY(), c->inqZ());
-      m_globalCursor->attach(this);
-    }
+    m_globalCursor->detach(this);
+    m_globalCursor->setCursor(c->inqX(), c->inqY(), c->inqZ());
+    m_globalCursor->attach(this);    
+  }
+  // 0 1 0 1
+  if( local && !m_opts.inqUseSharedVolume() && m_opts.inqUseSharedLocation() && !m_opts.inqVolumeIndexingWithinView() ) {
+    m_globalCursor->detach(this);
+    m_globalCursor->setCursor(c->inqX(), c->inqY(), c->inqZ());
+    m_globalCursor->attach(this);    
+  }
+  // 0 1 1 0
+  if( local && !m_opts.inqUseSharedVolume() && !m_opts.inqUseSharedLocation() && m_opts.inqVolumeIndexingWithinView() ) {
+    for_each( m_overlayList->begin(), m_overlayList->end(), SetVolume(mi->getDs()->inqCurrentVolume()) );
+  }
+  // 0 1 1 1
+  if( local && !m_opts.inqUseSharedVolume() && !m_opts.inqUseSharedLocation() && m_opts.inqVolumeIndexingWithinView() ) {
+    mi->getDs()->setCurrentVolume(c->inqV());
+  }
+  // 1 0 0 0
+  if( !local && m_opts.inqUseSharedVolume() && m_opts.inqUseSharedLocation() && m_opts.inqVolumeIndexingWithinView() ) {
+    for_each( m_overlayList->begin(), m_overlayList->end(), SetVolume(c->inqV()) );
+    m_cursor->detach(this);
+    m_cursor->setCursor(c);
+    m_cursor->attach(this);    
+  }
+  // 1 0 0 1
+  if( !local && m_opts.inqUseSharedVolume() && m_opts.inqUseSharedLocation() && !m_opts.inqVolumeIndexingWithinView() ) {
+    mi->getDs()->setCurrentVolume(c->inqV());
+    m_cursor->detach(this);
+    m_cursor->setCursor(c);
+    m_cursor->attach(this);    
+  }
+  // 1 0 1 0
+  if( !local && m_opts.inqUseSharedVolume() && !m_opts.inqUseSharedLocation() && m_opts.inqVolumeIndexingWithinView() ) {
+    for_each( m_overlayList->begin(), m_overlayList->end(), SetVolume(c->inqV()) );
+    m_cursor->detach(this);
+    m_cursor->setVolume(c->inqV());
+    m_cursor->attach(this);
+  }
+  // 1 0 1 1
+  if( !local && m_opts.inqUseSharedVolume() && !m_opts.inqUseSharedLocation() && !m_opts.inqVolumeIndexingWithinView() ) {
+    mi->getDs()->setCurrentVolume(c->inqV());
+    m_cursor->detach(this);
+    m_cursor->setVolume(c->inqV());
+    m_cursor->attach(this);
+  }
+  // 1 1 0 0
+  if( !local && !m_opts.inqUseSharedVolume() && m_opts.inqUseSharedLocation() && m_opts.inqVolumeIndexingWithinView() ) {
+    for_each( m_overlayList->begin(), m_overlayList->end(), SetVolume(mi->getDs()->inqCurrentVolume()) );
+    m_cursor->detach(this);
+    m_cursor->setCursor(c->inqX(), c->inqY(), c->inqZ());
+    m_cursor->attach(this);    
+  }
+  // 1 1 0 1
+  if( !local && !m_opts.inqUseSharedVolume() && m_opts.inqUseSharedLocation() && !m_opts.inqVolumeIndexingWithinView() ) {
+    m_cursor->detach(this);
+    m_cursor->setCursor(c->inqX(), c->inqY(), c->inqZ());
+    m_cursor->attach(this);    
+  }
+  // 1 1 1 0
+  if( !local && !m_opts.inqUseSharedVolume() && !m_opts.inqUseSharedLocation() && m_opts.inqVolumeIndexingWithinView() ) {
+    for_each( m_overlayList->begin(), m_overlayList->end(), SetVolume(mi->getDs()->inqCurrentVolume()) );
+  }
+  // 1 1 1 1
+  // Do nothing
 }
 
 void ImageWidget::update(const OverlayList* i, OverlayListMsg msg)
