@@ -22,7 +22,8 @@ public:
   LightboxWidget(QWidget *parent,ImageGroup::Handle i,
                  OverlayList::Handle ol, Cursor::Handle& c);
   virtual ~LightboxWidget();
-  virtual void update(const Cursor::Handle& c);
+
+  //  virtual void update(const Cursor::Handle& c);
 
   virtual void resizeEvent(QResizeEvent*);
 
@@ -34,6 +35,7 @@ public slots:
   void scrolled(int);
   void repaintSlices();
   void setZoom(int);
+  void print();
 
 private:
   void layoutSlices() const;
