@@ -54,6 +54,7 @@ void MeshOptionsDialog::populateMeshList(vector<VTKMeshSurface::Handle>& m)
 	m_lower->setText( QString("%1").arg(mh->inqLower()) );
 	m_upper->setText( QString("%1").arg(mh->inqUpper()) );
 	m_showGlyphs->setChecked( mh->inqShowGlyphs() );
+	m_showCellData->setChecked( mh->inqShowCellData() );
       }
     }
 }
@@ -63,6 +64,11 @@ void MeshOptionsDialog::showGlyphs(bool y)
   m_impl->m_meshes.at(m_impl->m_selectedMesh)->showGlyphs(y);
 }
 
+void MeshOptionsDialog::showCellData(bool y)
+{
+  m_impl->m_meshes.at(m_impl->m_selectedMesh)->showCellData(y);
+}
+
 void MeshOptionsDialog::setMesh(int meshId)
 {
   m_impl->m_selectedMesh = meshId;
@@ -71,6 +77,7 @@ void MeshOptionsDialog::setMesh(int meshId)
     m_lower->setText( QString("%1").arg(mh->inqLower()) );
     m_upper->setText( QString("%1").arg(mh->inqUpper()) );
     m_showGlyphs->setChecked( mh->inqShowGlyphs() );
+    m_showCellData->setChecked( mh->inqShowCellData() );
   }
 }
 
