@@ -8,6 +8,10 @@
 
 #include "modetoolbar.h"
 
+#include <qtooltip.h>
+
+using namespace std;
+
 ModeToolBarWidget::ModeToolBarWidget(QWidget *parent): 
   ModeToolbarBase(parent)
 {
@@ -21,3 +25,9 @@ ModeToolBarWidget::~ModeToolBarWidget()
 {
 }
 
+void
+ModeToolBarWidget::setSwitchHelpText(const string& s)
+{
+  QToolTip::add(m_switchViewsButton, s);
+}
+
