@@ -10,6 +10,7 @@
 #define MODETOOLBAR_H
 
 #include <qtoolbutton.h>
+#include <string>
 
 #include "slicewidget.h"
 #include "modetoolbarbase.h"
@@ -26,11 +27,14 @@ public:
   void enableSliceRollMode(bool on) { m_sliceRollButton->setEnabled(on);   }
   void enableSwitchViews(bool on)   { m_switchViewsButton->setEnabled(on); }
   bool inqMovieMode() { return m_movieModeButton->isOn(); }
+  void setSwitchHelpText(const std::string&);
 
 signals:
   void sliceRollStateChanged(int);
   void movieStateChanged(int);
   void switchViewsClicked();
+  void optionsClicked();
+  void printClicked();
 };
 
 #endif
