@@ -23,6 +23,8 @@ class OrthoWidget : public ImageWidget
 {
   Q_OBJECT
 public:
+  typedef enum {Traditional=0, InRow, InColumn} Layout;
+
   OrthoWidget(QWidget *parent, ImageGroup::Handle& i, 
               OverlayList::Handle ol, Cursor::Handle& c );
   virtual ~OrthoWidget();
@@ -32,8 +34,13 @@ public:
 signals:
   void  volChanged(int n);
 
+public slots:
+  void changeView();
+  void print();
+
 private:
   void setLabels(const OverlayList*);
+  void setLayout();
 
   QTimer            *m_timer;
   //SliceListHandle    m_slices;
@@ -43,6 +50,7 @@ private:
   QGridLayout       *m_grid; 
   ImageGroup::Handle m_image;
   QWidget           *m_centralWidget;
+  Layout             m_layout;
 };
 
 #endif
