@@ -22,8 +22,6 @@
 class Preferences: public QSettings
 {
 public:
-  typedef boost::shared_ptr<Preferences> Handle;
-
   std::string inqFSLDir() const;
   std::string inqMni152() const;
   std::string inqAssistantPath() const;
@@ -38,14 +36,14 @@ public:
   void setAtlasPath(const std::string&);
   void setGeometry(const QRect&);
 
-  static Handle getInstance();
-
-private:
   Preferences();
+  virtual ~Preferences() {}
+private:
 
-  static Handle m_instance;
-
-  struct Implementation;  
-  const std::auto_ptr< Implementation > m_impl;
+  mutable std::string m_assistantpath;
+  mutable std::string m_atlaspath;
+  mutable std::string m_fsldir;
+  mutable std::string m_mni;
+  int m_w, m_h, m_x, m_y;
 };
 
