@@ -6,22 +6,22 @@
 
 PropertiesDialogImpl::PropertiesDialogImpl(QWidget *parent)
 {
-  Preferences::Handle prefs=Preferences::getInstance();
+  Preferences prefs;
   
-  m_fslDir->setText(prefs->inqFSLDir());
-  m_mniImage->setText(prefs->inqMni152());
-  m_atlasPath->setText(prefs->inqAtlasPath());
-  m_assistantPath->setText(prefs->inqAssistantPath());
+  m_fslDir->setText(prefs.inqFSLDir());
+  m_mniImage->setText(prefs.inqMni152());
+  m_atlasPath->setText(prefs.inqAtlasPath());
+  m_assistantPath->setText(prefs.inqAssistantPath());
 }
 
 void PropertiesDialogImpl::commit()
 {
-  Preferences::Handle prefs=Preferences::getInstance();
+  Preferences prefs;
   
-  prefs->setFSLDir(m_fslDir->text());
-  prefs->setMni152(m_mniImage->text());
-  prefs->setAssistantPath(m_assistantPath->text());
-  prefs->setAtlasPath(m_atlasPath->text());
+  prefs.setFSLDir(m_fslDir->text());
+  prefs.setMni152(m_mniImage->text());
+  prefs.setAssistantPath(m_assistantPath->text());
+  prefs.setAtlasPath(m_atlasPath->text());
 }
 
 PropertiesDialogImpl::~PropertiesDialogImpl()
