@@ -4,14 +4,15 @@
 /* CCOPYRIGHT */
 
 #include "propertiesdialog.h"
-#include "properties.h"
 
 class PropertiesDialogImpl : public PropertiesDialog
 {
- public:
-  static Properties::Handle getProperties(QWidget *);
+public:
+  static void getProperties(QWidget *);
+
+private:
+  void commit();
 
- private:
   PropertiesDialogImpl(QWidget *);
   ~PropertiesDialogImpl();
 };
