@@ -22,17 +22,18 @@ public:
               OverlayList::Handle ol,
               Cursor::Handle& c);
   virtual ~SingleWidget();
-  virtual void update(const Cursor::Handle& c);
+  //  virtual void update(const Cursor::Handle& c);
 
 signals:
  
   void  volChanged(int);
 
 private slots:
-
   void nextSlice();
   void toggleSliceRoll(int);
   void changeView();
+  void setMovieFrameRate(int);
+  void print();
 
 private:
   void newSlice(int orient, int mode);
