@@ -21,6 +21,7 @@
 SliceView::SliceView(QWidget* parent, const char *name):
   SliceViewBase(parent, name)
 {
+  //  setBackgroundColor(QColor(0, 0, 0));
   delete m_pixmapLabel;
 }
 
@@ -41,16 +42,31 @@ void SliceView::setLabelsState(LabelState s)
       m_westLabel->setEnabled(false);
       break;
     case Disabled:
-    default:
+      m_northLabel->setText("");
+      m_southLabel->setText("");
+      m_eastLabel->setText("");
+      m_westLabel->setText("");
+   default:
       break;
     }      
 }
+
 void SliceView::setSliceWidget(SliceWidget* slice)
 {
+  m_slice = slice;
   m_gridLayout->addWidget(slice, 1, 1);
   slice->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
 }
 
+QPixmap SliceView::getPixmap() const
+{
+  QPixmap pm(size());
+
+  bitBlt(&pm,0,0,this);
+
+  return pm;
+}
+
 void SliceView::setNorthText(const std::string& s)
 {
   m_northLabel->setText(s);
