@@ -38,6 +38,11 @@ public:
   void setWestText(const std::string& s);
 
   void setLabelsState(LabelState s);
+
+  QPixmap getPixmap() const;
+
+private:
+  SliceWidget *m_slice;
 };
 
 #endif
