@@ -8,7 +8,7 @@
 
 
 /****************************************************************************
-** $Id: slicewidget.cpp,v 1.201.4.7 2009/04/23 10:29:13 flitney Exp $
+** $Id: slicewidget.cpp,v 1.204.2.2 2010/04/19 15:46:30 flitney Exp $
 **
 ** Copyright (C) 2002 University of Oxford.  All rights reserved.
 **
@@ -451,9 +451,11 @@ void SliceWidget::paintImages()
       while(!m_store->currentEmpty())
 	{
 	  ImageData::Handle i = m_store->current();
-	  if(i->inqVisibility() && (i->inqDtiDisplay() != DtiDisplay(Lines)))
+	  if(i->inqVisibility() && (i->inqDtiDisplay() != DtiDisplay(Lines)) && 
+	     (i->inqDtiDisplay() != DtiDisplay(LinesRGB)) )
             {
-	      ImageBuffer::blendBuffers(m_displayPixels, i->getBuffer(), i->inqTransparency(), isBottomImage, inqWidth()*inqHeight());    
+	      ImageBuffer::blendBuffers(m_displayPixels, i->getBuffer(), i->inqTransparency(), 
+					isBottomImage, inqWidth()*inqHeight());    
               isBottomImage = false;
             }
 
@@ -1280,6 +1282,20 @@ void SagittalWidget::setCursorSlice(short s)
   m_cursor->setCursor(s, m_cursor->inqY(), m_cursor->inqZ());
 }  
 
+// QColor SliceWidget::getDTIVectorColor(const Image::Handle& i,
+// 				      int x, int y, int z)
+// {
+//   Volume::Handle vR(i->getImage()->getVolume(0));
+//   Volume::Handle vG(i->getImage()->getVolume(1));
+//   Volume::Handle vB(i->getImage()->getVolume(2));
+
+//   int r = fabs(vR->value(m_slice, y, z)) * 255;
+//   int g = fabs(vG->value(m_slice, y, z)) * 255;
+//   int b = fabs(vB->value(m_slice, y, z)) * 255;
+
+//   return QColor(r, g, b);  
+// }
+
 void SagittalWidget::drawDtiLines()
 {
   m_store->resetPos();
@@ -1291,7 +1307,8 @@ void SagittalWidget::drawDtiLines()
       ImageData::Handle i(m_store->current());
       ImageInfo::Handle info(i->getImage()->getInfo());
 
-      if( i->inqVisibility() && (i->inqDtiDisplay() == DtiDisplay(Lines)) )
+      if( i->inqVisibility() && ( (i->inqDtiDisplay() == DtiDisplay(Lines)) ||
+				  (i->inqDtiDisplay() == DtiDisplay(LinesRGB)) ) )
 	{
 	  int yVec,zVec;
 
@@ -1310,9 +1327,10 @@ void SagittalWidget::drawDtiLines()
 		{
 		  yVec = int(vG->value(m_slice, y, z)*( 255.0/info->inqYDim() )*minDimension);
 		  zVec = int(vB->value(m_slice, y, z)*( 255.0/info->inqZDim() )*minDimension);
-		  //qDebug("yVec = %d, zVec = %d", yVec, zVec);
 		  if(yVec != 0 || zVec != 0)
 		    {
+		      if( i->inqDtiDisplay() == DtiDisplay(LinesRGB) )
+			m_paint.setPen(getDTIVectorColor(i->getImage(), m_slice, y, z));
 		      m_paint.drawLine((y*256) + 128 - int( 0.5 * yVec),(z*256) + 128 - int( 0.5 * zVec),
 				       (y*256) + 128 + int( 0.5 * yVec),(z*256) + 128 + int( 0.5 * zVec));
 		    }
@@ -1447,7 +1465,8 @@ void AxialWidget::drawDtiLines()
       ImageData::Handle i(m_store->current());
       ImageInfo::Handle info(i->getImage()->getInfo());
 
-      if( i->inqVisibility() && (i->inqDtiDisplay() == DtiDisplay(Lines)) )
+      if( i->inqVisibility() && ( (i->inqDtiDisplay() == DtiDisplay(Lines)) || 
+				  (i->inqDtiDisplay() == DtiDisplay(LinesRGB)) ) )
 	{
 	  int xVec,yVec;
 	  
@@ -1469,10 +1488,11 @@ void AxialWidget::drawDtiLines()
 		{          
 		  xVec = int(vR->value(x, y, m_slice)*( 255.0/info->inqXDim() )*minDimension);
 		  yVec = int(vG->value(x, y, m_slice)*( 255.0/info->inqYDim() )*minDimension);
-		  if(!info->isStoredRadiological()) xVec = -xVec;
 		  //qDebug("xVec = %d, yVec = %d", xVec, yVec);
 		  if(xVec != 0 || yVec != 0)
 		    {
+		      if( i->inqDtiDisplay() == DtiDisplay(LinesRGB) )
+			m_paint.setPen(getDTIVectorColor(i->getImage(), x, y, m_slice));
 		      m_paint.drawLine((x*256) + 128 - int( 0.5 * xVec),(y*256) + 128 - int( 0.5 * yVec),
 				       (x*256) + 128 + int( 0.5 * xVec),(y*256) + 128 + int( 0.5 * yVec));
 		    }
@@ -1575,9 +1595,10 @@ void CoronalWidget::drawDtiLines()
   while(!m_store->currentEmpty())
     {
     ImageData::Handle i(m_store->current());
-   ImageInfo::Handle info(i->getImage()->getInfo());
+    ImageInfo::Handle info(i->getImage()->getInfo());
 
-    if( i->inqVisibility() && (i->inqDtiDisplay() == DtiDisplay(Lines)) )
+    if( i->inqVisibility() && ( (i->inqDtiDisplay() == DtiDisplay(Lines)) || 
+				(i->inqDtiDisplay() == DtiDisplay(LinesRGB)) ) )
       {
         int xVec,zVec;
 
@@ -1596,10 +1617,11 @@ void CoronalWidget::drawDtiLines()
             {          
               xVec = int(vR->value(x, m_slice, z)*( 255.0/info->inqXDim() )*minDimension);
               zVec = int(vB->value(x, m_slice, z)*( 255.0/info->inqZDim() )*minDimension);
-	      if(!info->isStoredRadiological()) xVec = -xVec;
 	      //qDebug("xVec = %d, zVec = %d", xVec, zVec);
               if(xVec != 0 || zVec != 0)
                 {
+		  if( i->inqDtiDisplay() == DtiDisplay(LinesRGB) )
+		    m_paint.setPen(getDTIVectorColor(i->getImage(), x, m_slice, z));
                   m_paint.drawLine((x*256) + 128 - int( 0.5 * xVec),(z*256) + 128 - int( 0.5 * zVec),
                                    (x*256) + 128 + int( 0.5 * xVec),(z*256) + 128 + int( 0.5 * zVec));
                 }
