@@ -87,6 +87,20 @@ public:
 
   QPixmap getPixmap() const;
 
+  QColor getDTIVectorColor(const Image::Handle& i,
+			   int x, int y, int z)
+  {
+    Volume::Handle vR(i->getVolume(0));
+    Volume::Handle vG(i->getVolume(1));
+    Volume::Handle vB(i->getVolume(2));
+    
+    int r = int(fabs(vR->value(x, y, z)) * 255);
+    int g = int(fabs(vG->value(x, y, z)) * 255);
+    int b = int(fabs(vB->value(x, y, z)) * 255);
+
+    return QColor(r, g, b);  
+  }
+
   void setNorthText(const std::string& s);
   void setSouthText(const std::string& s);
   void setWestText(const std::string& s);
