@@ -17,7 +17,7 @@ class SplashScreen : public QFrame
 {
   Q_OBJECT
 public:
-  SplashScreen(QWidget *parent, const OverlayOptionList& overlays, const char *name=0);
+  SplashScreen(QWidget *parent, ApplicationOptions& opts, const char *name=0);
   virtual ~SplashScreen();
   
   void showEvent(QShowEvent *);
@@ -26,7 +26,7 @@ public slots:
   void runApplication();
 
 private:
-  const OverlayOptionList& m_overlays;
+  ApplicationOptions& m_options;
 };
 
 #endif
