@@ -32,9 +32,8 @@ public:
 
   ViewWidget(QWidget *parent);
   virtual ~ViewWidget();
-  virtual OverlayList::Handle getOverlayList(){OverlayList::Handle h;return h;};
-  virtual void update(const Cursor::Handle& c){};
-
+  virtual OverlayList::Handle getOverlayList(){OverlayList::Handle h;return h;}
+  virtual void update(const Cursor::Handle& c){}
 
 signals:
   void message(const QString&, int);
@@ -43,8 +42,11 @@ signals:
   void modeChanged(int);
   void addLookUpTable();
   void windowClose(QCloseEvent*);
+  void overlayEvent();
+
 public slots:
   virtual void setImageCursor(int, int, int);
+
 protected:
   virtual void closeEvent(QCloseEvent*);
 };
