@@ -1077,6 +1077,13 @@ VTKWidget::~VTKWidget()
   m_impl->m_props.detach(this);
 }
 
+void VTKWidget::update(const BriCon* bc)
+{
+  TRACKER("VTKWidget::update(const BriCon*)");
+
+  m_impl->m_surfMapper->SetScalarRange(bc->inqMin(), bc->inqMax());  
+}
+
 void VTKWidget::addMesh()
 {
   //FileDialog to find mesh file
